@@ -34,9 +34,7 @@
 #include "eel-gtk-extensions.h"
 #include "eel-gtk-macros.h"
 
-#include <gtk/gtkwindow.h>
-#include <gtk/gtkvbox.h>
-#include <gtk/gtksignal.h>
+#include <gtk/gtk.h>
 
 #include <stdlib.h>
 #include <unistd.h>
