@@ -28,7 +28,7 @@
 #define EEL_GNOME_EXTENSIONS_H
 
 #include <glade/glade.h>
-#include <gtk/gtkwindow.h>
+#include <gtk/gtk.h>
 #include <bonobo/bonobo-property-bag-client.h>
 
 /* icon selection callback function. */
