@@ -37,21 +37,10 @@
 #include <X11/Xlib.h>
 #include <X11/Xatom.h>
 #include <gdk/gdk.h>
-#include <gdk/gdkkeysyms.h>
 #include <gdk/gdkprivate.h>
 #include <gdk/gdkx.h>
-#include <gtk/gtkalignment.h>
-#include <gtk/gtkdialog.h>
-#include <gtk/gtkdnd.h>
-#include <gtk/gtkhbox.h>
-#include <gtk/gtkimage.h>
-#include <gtk/gtkmain.h>
-#include <gtk/gtkrc.h>
-#include <gtk/gtkselection.h>
-#include <gtk/gtkseparatormenuitem.h>
-#include <gtk/gtksignal.h>
+#include <gtk/gtk.h>
 #include <math.h>
-
 #include "eel-marshal.h"
 #include "eel-marshal.c"
 
