@@ -1,7 +1,5 @@
 #include "test.h"
 
-#include <libart_lgpl/art_rgb.h>
-#include <libgnomevfs/gnome-vfs-utils.h>
 #include <unistd.h>
 
 void
@@ -20,7 +18,6 @@ test_init (int *argc,
 #else
 	gtk_init (argc, argv);
 #endif
-	gnome_vfs_init ();
 
 	eel_make_warnings_and_criticals_stop_in_debugger ();
 }
@@ -28,8 +25,6 @@ test_init (int *argc,
 int
 test_quit (int exit_code)
 {
-	/*gnome_vfs_shutdown ();*/
-
 	if (gtk_main_level () > 0) {
 		gtk_main_quit ();
 	}
@@ -80,7 +75,7 @@ test_gtk_widget_set_background_image (GtkWidget *widget,
 	background = eel_get_widget_background (widget);
 	
 	path = g_strconcat ("EEL_DATADIR", image_name, NULL);
-	uri = gnome_vfs_get_uri_from_local_path (path);
+	uri = g_filename_to_uri (path, NULL, NULL);
 	g_free (path);
 
 	eel_background_set_image_uri (background, uri);
@@ -165,60 +160,11 @@ test_window_set_title_with_pid (GtkWindow *window,
 	
 	g_return_if_fail (GTK_IS_WINDOW (window));
 
-	tmp = g_strdup_printf ("%d: %s", getpid (), title);
+	tmp = g_strdup_printf ("%d: %s", (int) getpid (), title);
 	gtk_window_set_title (GTK_WINDOW (window), tmp);
 	g_free (tmp);
 }
 
-void
-test_pixbuf_draw_rectangle_tiled (GdkPixbuf *pixbuf,
-				  const char *tile_name,
-				  int x0,
-				  int y0,
-				  int x1,
-				  int y1,
-				  int opacity)
-{
-	ArtIRect area;
-	GdkPixbuf *tile_pixbuf;
-
-	g_return_if_fail (eel_gdk_pixbuf_is_valid (pixbuf));
-	g_return_if_fail (tile_name != NULL);
- 	g_return_if_fail (opacity > EEL_OPACITY_FULLY_TRANSPARENT);
- 	g_return_if_fail (opacity <= EEL_OPACITY_FULLY_OPAQUE);
-
-	tile_pixbuf = test_pixbuf_new_named (tile_name, 1.0);
-
- 	g_return_if_fail (tile_pixbuf != NULL);
-
-	if (x0 == -1 && y0 == -1 && x1 == -1 && y1 == -1) {
-		EelDimensions dimensions;
-		dimensions = eel_gdk_pixbuf_get_dimensions (pixbuf);
-		area = eel_art_irect_assign_dimensions (0, 0, dimensions);
-	} else {
-		g_return_if_fail (x0 >= 0);
-		g_return_if_fail (y0 >= 0);
-		g_return_if_fail (x1 > x0);
-		g_return_if_fail (y1 > y0);
-
-		area.x0 = x0;
-		area.y0 = y0;
-		area.x1 = x1;
-		area.y1 = y1;
-	}
-	
-	eel_gdk_pixbuf_draw_to_pixbuf_tiled (tile_pixbuf,
-					     pixbuf,
-					     area,
-					     gdk_pixbuf_get_width (tile_pixbuf),
-					     gdk_pixbuf_get_height (tile_pixbuf),
-					     0,
-					     0,
-					     opacity,
-					     GDK_INTERP_NEAREST);
-
-	g_object_unref (tile_pixbuf);
-}
 
 char *
 eel_pixmap_file (const char *partial_path)
